[//]: # (user-facing readme)

# Arthur API Client
[Arthur](https://www.arthur.ai/) is the platform for centralized monitoring of production models. 
We help data scientists, product owners, and business leaders accelerate model operations to optimize 
for accuracy, explainability, and fairness. As a model- and infrastructure-agnostic platform, Arthur 
adds a layer of intelligence to your AI stack and scales with your deployments.

Our API Client makes it easy to integrate your models with the Arthur platform. For help getting started or 
using the SDK, check out [our documentation](https://docs.arthur.ai/).
